Command-line interface
======================

The command line interface provides easy and direct access to
all functionality in omega-ml.

.. toctree::
   :maxdepth: 2

   intro
   models
   datasets
   scripts
   jobs
   runtime
